==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/SQLInstanceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Set the server/instance-level settings for SQL Server.
 * @property collation SQL Server Collation.
 * @property isIfiEnabled SQL Server IFI.
 * @property isLpimEnabled SQL Server LPIM.
 * @property isOptimizeForAdHocWorkloadsEnabled SQL Server Optimize for Adhoc workloads.
 * @property maxDop SQL Server MAXDOP.
 * @property maxServerMemoryMB SQL Server maximum memory.
 * @property minServerMemoryMB SQL Server minimum memory.
 */
public data class SQLInstanceSettingsArgs(
    public val collation: Output<String>? = null,
    public val isIfiEnabled: Output<Boolean>? = null,
    public val isLpimEnabled: Output<Boolean>? = null,
    public val isOptimizeForAdHocWorkloadsEnabled: Output<Boolean>? = null,
    public val maxDop: Output<Int>? = null,
    public val maxServerMemoryMB: Output<Int>? = null,
    public val minServerMemoryMB: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs.builder()
            .collation(collation?.applyValue({ args0 -> args0 }))
            .isIfiEnabled(isIfiEnabled?.applyValue({ args0 -> args0 }))
            .isLpimEnabled(isLpimEnabled?.applyValue({ args0 -> args0 }))
            .isOptimizeForAdHocWorkloadsEnabled(
                isOptimizeForAdHocWorkloadsEnabled?.applyValue({ args0 ->
                    args0
                }),
            )
            .maxDop(maxDop?.applyValue({ args0 -> args0 }))
            .maxServerMemoryMB(maxServerMemoryMB?.applyValue({ args0 -> args0 }))
            .minServerMemoryMB(minServerMemoryMB?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SQLInstanceSettingsArgs].
 */
@PulumiTagMarker
public class SQLInstanceSettingsArgsBuilder internal constructor() {
    private var collation: Output<String>? = null

    private var isIfiEnabled: Output<Boolean>? = null

    private var isLpimEnabled: Output<Boolean>? = null

    private var isOptimizeForAdHocWorkloadsEnabled: Output<Boolean>? = null

    private var maxDop: Output<Int>? = null

    private var maxServerMemoryMB: Output<Int>? = null

    private var minServerMemoryMB: Output<Int>? = null

    /**
     * @param value SQL Server Collation.
     */
    @JvmName("bimgijsggvywnypf")
    public suspend fun collation(`value`: Output<String>) {
        this.collation = value
    }

    /**
     * @param value SQL Server IFI.
     */
    @JvmName("igcymrxurvqnnmkn")
    public suspend fun isIfiEnabled(`value`: Output<Boolean>) {
        this.isIfiEnabled = value
    }

    /**
     * @param value SQL Server LPIM.
     */
    @JvmName("yidxhpqoeffweptx")
    public suspend fun isLpimEnabled(`value`: Output<Boolean>) {
        this.isLpimEnabled = value
    }

    /**
     * @param value SQL Server Optimize for Adhoc workloads.
     */
    @JvmName("vmobbluotoiommjq")
    public suspend fun isOptimizeForAdHocWorkloadsEnabled(`value`: Output<Boolean>) {
        this.isOptimizeForAdHocWorkloadsEnabled = value
    }

    /**
     * @param value SQL Server MAXDOP.
     */
    @JvmName("xbghocefvahdrebr")
    public suspend fun maxDop(`value`: Output<Int>) {
        this.maxDop = value
    }

    /**
     * @param value SQL Server maximum memory.
     */
    @JvmName("dbcbkbpwlhxvtldk")
    public suspend fun maxServerMemoryMB(`value`: Output<Int>) {
        this.maxServerMemoryMB = value
    }

    /**
     * @param value SQL Server minimum memory.
     */
    @JvmName("xjfykktyfdaician")
    public suspend fun minServerMemoryMB(`value`: Output<Int>) {
        this.minServerMemoryMB = value
    }

    /**
     * @param value SQL Server Collation.
     */
    @JvmName("ugfparwvcfdsfqqj")
    public suspend fun collation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collation = mapped
    }

    /**
     * @param value SQL Server IFI.
     */
    @JvmName("mujbvvlugnjghyqh")
    public suspend fun isIfiEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isIfiEnabled = mapped
    }

    /**
     * @param value SQL Server LPIM.
     */
    @JvmName("qlitynhwekewtfor")
    public suspend fun isLpimEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isLpimEnabled = mapped
    }

    /**
     * @param value SQL Server Optimize for Adhoc workloads.
     */
    @JvmName("yeqyghhwcegssdtl")
    public suspend fun isOptimizeForAdHocWorkloadsEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isOptimizeForAdHocWorkloadsEnabled = mapped
    }

    /**
     * @param value SQL Server MAXDOP.
     */
    @JvmName("olreklmgrlklrgga")
    public suspend fun maxDop(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxDop = mapped
    }

    /**
     * @param value SQL Server maximum memory.
     */
    @JvmName("pfnrofsrhsxvfbpd")
    public suspend fun maxServerMemoryMB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxServerMemoryMB = mapped
    }

    /**
     * @param value SQL Server minimum memory.
     */
    @JvmName("obghnhbcwvowxggv")
    public suspend fun minServerMemoryMB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minServerMemoryMB = mapped
    }

    internal fun build(): SQLInstanceSettingsArgs = SQLInstanceSettingsArgs(
        collation = collation,
        isIfiEnabled = isIfiEnabled,
        isLpimEnabled = isLpimEnabled,
        isOptimizeForAdHocWorkloadsEnabled = isOptimizeForAdHocWorkloadsEnabled,
        maxDop = maxDop,
        maxServerMemoryMB = maxServerMemoryMB,
        minServerMemoryMB = minServerMemoryMB,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/SQLInstanceSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Set the server/instance-level settings for SQL Server.
 * @property collation SQL Server Collation.
 * @property isIfiEnabled SQL Server IFI.
 * @property isLpimEnabled SQL Server LPIM.
 * @property isOptimizeForAdHocWorkloadsEnabled SQL Server Optimize for Adhoc workloads.
 * @property maxDop SQL Server MAXDOP.
 * @property maxServerMemoryMB SQL Server maximum memory.
 * @property minServerMemoryMB SQL Server minimum memory.
 */
public data class SQLInstanceSettingsArgs(
    public val collation: Output<String>? = null,
    public val isIfiEnabled: Output<Boolean>? = null,
    public val isLpimEnabled: Output<Boolean>? = null,
    public val isOptimizeForAdHocWorkloadsEnabled: Output<Boolean>? = null,
    public val maxDop: Output<Int>? = null,
    public val maxServerMemoryMB: Output<Int>? = null,
    public val minServerMemoryMB: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.SQLInstanceSettingsArgs.builder()
            .collation(collation?.applyValue({ args0 -> args0 }))
            .isIfiEnabled(isIfiEnabled?.applyValue({ args0 -> args0 }))
            .isLpimEnabled(isLpimEnabled?.applyValue({ args0 -> args0 }))
            .isOptimizeForAdHocWorkloadsEnabled(
                isOptimizeForAdHocWorkloadsEnabled?.applyValue({ args0 ->
                    args0
                }),
            )
            .maxDop(maxDop?.applyValue({ args0 -> args0 }))
            .maxServerMemoryMB(maxServerMemoryMB?.applyValue({ args0 -> args0 }))
            .minServerMemoryMB(minServerMemoryMB?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SQLInstanceSettingsArgs].
 */
@PulumiTagMarker
public class SQLInstanceSettingsArgsBuilder internal constructor() {
    private var collation: Output<String>? = null

    private var isIfiEnabled: Output<Boolean>? = null

    private var isLpimEnabled: Output<Boolean>? = null

    private var isOptimizeForAdHocWorkloadsEnabled: Output<Boolean>? = null

    private var maxDop: Output<Int>? = null

    private var maxServerMemoryMB: Output<Int>? = null

    private var minServerMemoryMB: Output<Int>? = null

    /**
     * @param value SQL Server Collation.
     */
    @JvmName("nuxcagarqxyynrpe")
    public suspend fun collation(`value`: Output<String>) {
        this.collation = value
    }

    /**
     * @param value SQL Server IFI.
     */
    @JvmName("dcswbnttmxyquakm")
    public suspend fun isIfiEnabled(`value`: Output<Boolean>) {
        this.isIfiEnabled = value
    }

    /**
     * @param value SQL Server LPIM.
     */
    @JvmName("jfmjdygeuonpssfk")
    public suspend fun isLpimEnabled(`value`: Output<Boolean>) {
        this.isLpimEnabled = value
    }

    /**
     * @param value SQL Server Optimize for Adhoc workloads.
     */
    @JvmName("ircavtdbnekckwtw")
    public suspend fun isOptimizeForAdHocWorkloadsEnabled(`value`: Output<Boolean>) {
        this.isOptimizeForAdHocWorkloadsEnabled = value
    }

    /**
     * @param value SQL Server MAXDOP.
     */
    @JvmName("yjumjfachawskpou")
    public suspend fun maxDop(`value`: Output<Int>) {
        this.maxDop = value
    }

    /**
     * @param value SQL Server maximum memory.
     */
    @JvmName("gckdpxuvgaokntnk")
    public suspend fun maxServerMemoryMB(`value`: Output<Int>) {
        this.maxServerMemoryMB = value
    }

    /**
     * @param value SQL Server minimum memory.
     */
    @JvmName("tqciodpxgkmtmcex")
    public suspend fun minServerMemoryMB(`value`: Output<Int>) {
        this.minServerMemoryMB = value
    }

    /**
     * @param value SQL Server Collation.
     */
    @JvmName("gptlrlbuimgbdnsy")
    public suspend fun collation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collation = mapped
    }

    /**
     * @param value SQL Server IFI.
     */
    @JvmName("hjprgsvmwxpsorpy")
    public suspend fun isIfiEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isIfiEnabled = mapped
    }

    /**
     * @param value SQL Server LPIM.
     */
    @JvmName("jnvqibdydjawpypg")
    public suspend fun isLpimEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isLpimEnabled = mapped
    }

    /**
     * @param value SQL Server Optimize for Adhoc workloads.
     */
    @JvmName("fplmluhweelktegb")
    public suspend fun isOptimizeForAdHocWorkloadsEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isOptimizeForAdHocWorkloadsEnabled = mapped
    }

    /**
     * @param value SQL Server MAXDOP.
     */
    @JvmName("swicxemhemfvkfcq")
    public suspend fun maxDop(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxDop = mapped
    }

    /**
     * @param value SQL Server maximum memory.
     */
    @JvmName("tkqdwfqhgcrrsdjd")
    public suspend fun maxServerMemoryMB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxServerMemoryMB = mapped
    }

    /**
     * @param value SQL Server minimum memory.
     */
    @JvmName("rkpjhpxorpofdbox")
    public suspend fun minServerMemoryMB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minServerMemoryMB = mapped
    }

    internal fun build(): SQLInstanceSettingsArgs = SQLInstanceSettingsArgs(
        collation = collation,
        isIfiEnabled = isIfiEnabled,
        isLpimEnabled = isLpimEnabled,
        isOptimizeForAdHocWorkloadsEnabled = isOptimizeForAdHocWorkloadsEnabled,
        maxDop = maxDop,
        maxServerMemoryMB = maxServerMemoryMB,
        minServerMemoryMB = minServerMemoryMB,
    )
}
